@@ -5,6 +5,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.utils.html import strip_tags
 from django.utils.text import Truncator
+from fields import MultiSelectField
 
 
 class TextWrapper(AbstractText):
@@ -14,9 +15,11 @@ class TextWrapper(AbstractText):
     class Meta:
         db_table = 'cmsplugin_text'
 
-    CHOICES = tuple((w[0], w[0]) for w in settings.CMS_TEXT_WRAPPERS)
-    wrapper = models.CharField(max_length=50, choices=CHOICES, blank=True,
-                               verbose_name=_('Wrap into'))
+    WRAPPERS = tuple((w[0], w[0]) for w in settings.CMS_TEXT_WRAPPERS)
+    CLASSES = tuple((k, w) for k, w in enumerate(settings.CMS_TEXT_WRAPPER_CLASSES))
+    wrapper = models.CharField(max_length=50, choices=WRAPPERS, blank=True, verbose_name=_('Wrap into'))
+    classes = MultiSelectField(max_length=250, blank=True, null=True, choices=CLASSES,
+                                verbose_name=_('Apply extra classes'))
 
     def __unicode__(self):
         if self.wrapper:
